package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseDeviceDebugging;
import com.hw.dms.service.IDmsBaseDeviceDebuggingService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 设备调试信息Controller
 * 
 * @author xins
 * @date 2024-01-02
 */
@RestController
@RequestMapping("/debugging")
public class DmsBaseDeviceDebuggingController extends BaseController
{
    @Autowired
    private IDmsBaseDeviceDebuggingService dmsBaseDeviceDebuggingService;

    /**
     * 查询设备调试信息列表
     */
    @RequiresPermissions("dms:debugging:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseDeviceDebugging dmsBaseDeviceDebugging)
    {
        startPage();
        List<DmsBaseDeviceDebugging> list = dmsBaseDeviceDebuggingService.selectDmsBaseDeviceDebuggingList(dmsBaseDeviceDebugging);
        return getDataTable(list);
    }

    /**
     * 导出设备调试信息列表
     */
    @RequiresPermissions("dms:debugging:export")
    @Log(title = "设备调试信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseDeviceDebugging dmsBaseDeviceDebugging)
    {
        List<DmsBaseDeviceDebugging> list = dmsBaseDeviceDebuggingService.selectDmsBaseDeviceDebuggingList(dmsBaseDeviceDebugging);
        ExcelUtil<DmsBaseDeviceDebugging> util = new ExcelUtil<DmsBaseDeviceDebugging>(DmsBaseDeviceDebugging.class);
        util.exportExcel(response, list, "设备调试信息数据");
    }

    /**
     * 获取设备调试信息详细信息
     */
    @RequiresPermissions("dms:debugging:query")
    @GetMapping(value = "/{deviceDebuggingId}")
    public AjaxResult getInfo(@PathVariable("deviceDebuggingId") Long deviceDebuggingId)
    {
        return success(dmsBaseDeviceDebuggingService.selectDmsBaseDeviceDebuggingByDeviceDebuggingId(deviceDebuggingId));
    }

    /**
     * 新增设备调试信息
     */
    @RequiresPermissions("dms:debugging:add")
    @Log(title = "设备调试信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseDeviceDebugging dmsBaseDeviceDebugging)
    {
        return toAjax(dmsBaseDeviceDebuggingService.insertDmsBaseDeviceDebugging(dmsBaseDeviceDebugging));
    }

    /**
     * 修改设备调试信息
     */
    @RequiresPermissions("dms:debugging:edit")
    @Log(title = "设备调试信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseDeviceDebugging dmsBaseDeviceDebugging)
    {
        return toAjax(dmsBaseDeviceDebuggingService.updateDmsBaseDeviceDebugging(dmsBaseDeviceDebugging));
    }

    /**
     * 删除设备调试信息
     */
    @RequiresPermissions("dms:debugging:remove")
    @Log(title = "设备调试信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deviceDebuggingIds}")
    public AjaxResult remove(@PathVariable Long[] deviceDebuggingIds)
    {
        return toAjax(dmsBaseDeviceDebuggingService.deleteDmsBaseDeviceDebuggingByDeviceDebuggingIds(deviceDebuggingIds));
    }
}
