package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseDeviceInstall;
import com.hw.dms.service.IDmsBaseDeviceInstallService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 设备安装信息Controller
 * 
 * @author xins
 * @date 2024-01-02
 */
@RestController
@RequestMapping("/install")
public class DmsBaseDeviceInstallController extends BaseController
{
    @Autowired
    private IDmsBaseDeviceInstallService dmsBaseDeviceInstallService;

    /**
     * 查询设备安装信息列表
     */
    @RequiresPermissions("dms:install:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseDeviceInstall dmsBaseDeviceInstall)
    {
        startPage();
        List<DmsBaseDeviceInstall> list = dmsBaseDeviceInstallService.selectDmsBaseDeviceInstallList(dmsBaseDeviceInstall);
        return getDataTable(list);
    }

    /**
     * 导出设备安装信息列表
     */
    @RequiresPermissions("dms:install:export")
    @Log(title = "设备安装信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseDeviceInstall dmsBaseDeviceInstall)
    {
        List<DmsBaseDeviceInstall> list = dmsBaseDeviceInstallService.selectDmsBaseDeviceInstallList(dmsBaseDeviceInstall);
        ExcelUtil<DmsBaseDeviceInstall> util = new ExcelUtil<DmsBaseDeviceInstall>(DmsBaseDeviceInstall.class);
        util.exportExcel(response, list, "设备安装信息数据");
    }

    /**
     * 获取设备安装信息详细信息
     */
    @RequiresPermissions("dms:install:query")
    @GetMapping(value = "/{deviceInstallId}")
    public AjaxResult getInfo(@PathVariable("deviceInstallId") Long deviceInstallId)
    {
        return success(dmsBaseDeviceInstallService.selectDmsBaseDeviceInstallByDeviceInstallId(deviceInstallId));
    }

    /**
     * 新增设备安装信息
     */
    @RequiresPermissions("dms:install:add")
    @Log(title = "设备安装信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseDeviceInstall dmsBaseDeviceInstall)
    {
        return toAjax(dmsBaseDeviceInstallService.insertDmsBaseDeviceInstall(dmsBaseDeviceInstall));
    }

    /**
     * 修改设备安装信息
     */
    @RequiresPermissions("dms:install:edit")
    @Log(title = "设备安装信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseDeviceInstall dmsBaseDeviceInstall)
    {
        return toAjax(dmsBaseDeviceInstallService.updateDmsBaseDeviceInstall(dmsBaseDeviceInstall));
    }

    /**
     * 删除设备安装信息
     */
    @RequiresPermissions("dms:install:remove")
    @Log(title = "设备安装信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deviceInstallIds}")
    public AjaxResult remove(@PathVariable Long[] deviceInstallIds)
    {
        return toAjax(dmsBaseDeviceInstallService.deleteDmsBaseDeviceInstallByDeviceInstallIds(deviceInstallIds));
    }
}
