package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseDeviceSuplier;
import com.hw.dms.service.IDmsBaseDeviceSuplierService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 设备供应商信息Controller
 *
 * @author xins
 * @date 2023-12-28
 */
@RestController
@RequestMapping("/suplier")
public class DmsBaseDeviceSuplierController extends BaseController
{
    @Autowired
    private IDmsBaseDeviceSuplierService dmsBaseDeviceSuplierService;

    /**
     * 查询设备供应商信息列表
     */
    @RequiresPermissions("dms:suplier:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseDeviceSuplier dmsBaseDeviceSuplier)
    {
        startPage();
        List<DmsBaseDeviceSuplier> list = dmsBaseDeviceSuplierService.selectDmsBaseDeviceSuplierList(dmsBaseDeviceSuplier);
        return getDataTable(list);
    }
    //todo 新加一个con 拿掉分页

    /**
     * 导出设备供应商信息列表
     */
    @RequiresPermissions("dms:suplier:export")
    @Log(title = "设备供应商信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseDeviceSuplier dmsBaseDeviceSuplier)
    {
        List<DmsBaseDeviceSuplier> list = dmsBaseDeviceSuplierService.selectDmsBaseDeviceSuplierList(dmsBaseDeviceSuplier);
        ExcelUtil<DmsBaseDeviceSuplier> util = new ExcelUtil<DmsBaseDeviceSuplier>(DmsBaseDeviceSuplier.class);
        util.exportExcel(response, list, "设备供应商信息数据");
    }

    /**
     * 获取设备供应商信息详细信息
     */
    @RequiresPermissions("dms:suplier:query")
    @GetMapping(value = "/{supplierId}")
    public AjaxResult getInfo(@PathVariable("supplierId") Long supplierId)
    {
        return success(dmsBaseDeviceSuplierService.selectDmsBaseDeviceSuplierBySupplierId(supplierId));
    }

    /**
     * 新增设备供应商信息
     */
    @RequiresPermissions("dms:suplier:add")
    @Log(title = "设备供应商信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseDeviceSuplier dmsBaseDeviceSuplier)
    {
        return toAjax(dmsBaseDeviceSuplierService.insertDmsBaseDeviceSuplier(dmsBaseDeviceSuplier));
    }

    /**
     * 修改设备供应商信息
     */
    @RequiresPermissions("dms:suplier:edit")
    @Log(title = "设备供应商信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseDeviceSuplier dmsBaseDeviceSuplier)
    {
        return toAjax(dmsBaseDeviceSuplierService.updateDmsBaseDeviceSuplier(dmsBaseDeviceSuplier));
    }

    /**
     * 删除设备供应商信息
     */
    @RequiresPermissions("dms:suplier:remove")
    @Log(title = "设备供应商信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{supplierIds}")
    public AjaxResult remove(@PathVariable Long[] supplierIds)
    {
        return toAjax(dmsBaseDeviceSuplierService.deleteDmsBaseDeviceSuplierBySupplierIds(supplierIds));
    }
}
