package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseMaintStation;
import com.hw.dms.service.IDmsBaseMaintStationService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 保养部位信息Controller
 * 
 * @author xins
 * @date 2024-01-05
 */
@RestController
@RequestMapping("/station")
public class DmsBaseMaintStationController extends BaseController
{
    @Autowired
    private IDmsBaseMaintStationService dmsBaseMaintStationService;

    /**
     * 查询保养部位信息列表
     */
    @RequiresPermissions("dms:station:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseMaintStation dmsBaseMaintStation)
    {
        startPage();
        List<DmsBaseMaintStation> list = dmsBaseMaintStationService.selectDmsBaseMaintStationList(dmsBaseMaintStation);
        return getDataTable(list);
    }

    /**
     * 导出保养部位信息列表
     */
    @RequiresPermissions("dms:station:export")
    @Log(title = "保养部位信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseMaintStation dmsBaseMaintStation)
    {
        List<DmsBaseMaintStation> list = dmsBaseMaintStationService.selectDmsBaseMaintStationList(dmsBaseMaintStation);
        ExcelUtil<DmsBaseMaintStation> util = new ExcelUtil<DmsBaseMaintStation>(DmsBaseMaintStation.class);
        util.exportExcel(response, list, "保养部位信息数据");
    }

    /**
     * 获取保养部位信息详细信息
     */
    @RequiresPermissions("dms:station:query")
    @GetMapping(value = "/{maintStationId}")
    public AjaxResult getInfo(@PathVariable("maintStationId") Long maintStationId)
    {
        return success(dmsBaseMaintStationService.selectDmsBaseMaintStationByMaintStationId(maintStationId));
    }

    /**
     * 新增保养部位信息
     */
    @RequiresPermissions("dms:station:add")
    @Log(title = "保养部位信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseMaintStation dmsBaseMaintStation)
    {
        return toAjax(dmsBaseMaintStationService.insertDmsBaseMaintStation(dmsBaseMaintStation));
    }

    /**
     * 修改保养部位信息
     */
    @RequiresPermissions("dms:station:edit")
    @Log(title = "保养部位信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseMaintStation dmsBaseMaintStation)
    {
        return toAjax(dmsBaseMaintStationService.updateDmsBaseMaintStation(dmsBaseMaintStation));
    }

    /**
     * 删除保养部位信息
     */
    @RequiresPermissions("dms:station:remove")
    @Log(title = "保养部位信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{maintStationIds}")
    public AjaxResult remove(@PathVariable Long[] maintStationIds)
    {
        return toAjax(dmsBaseMaintStationService.deleteDmsBaseMaintStationByMaintStationIds(maintStationIds));
    }
}
