package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsPlanMaint;
import com.hw.dms.service.IDmsPlanMaintService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 保养计划信息Controller
 * 
 * @author xins
 * @date 2024-01-08
 */
@RestController
@RequestMapping("/maint")
public class DmsPlanMaintController extends BaseController
{
    @Autowired
    private IDmsPlanMaintService dmsPlanMaintService;

    /**
     * 查询保养计划信息列表
     */
    @RequiresPermissions("dms:maint:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsPlanMaint dmsPlanMaint)
    {
        startPage();
        List<DmsPlanMaint> list = dmsPlanMaintService.selectDmsPlanMaintList(dmsPlanMaint);
        return getDataTable(list);
    }

    /**
     * 导出保养计划信息列表
     */
    @RequiresPermissions("dms:maint:export")
    @Log(title = "保养计划信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsPlanMaint dmsPlanMaint)
    {
        List<DmsPlanMaint> list = dmsPlanMaintService.selectDmsPlanMaintList(dmsPlanMaint);
        ExcelUtil<DmsPlanMaint> util = new ExcelUtil<DmsPlanMaint>(DmsPlanMaint.class);
        util.exportExcel(response, list, "保养计划信息数据");
    }

    /**
     * 获取保养计划信息详细信息
     */
    @RequiresPermissions("dms:maint:query")
    @GetMapping(value = "/{planMaintId}")
    public AjaxResult getInfo(@PathVariable("planMaintId") Long planMaintId)
    {
        return success(dmsPlanMaintService.selectDmsPlanMaintByPlanMaintId(planMaintId));
    }

    /**
     * 新增保养计划信息
     */
    @RequiresPermissions("dms:maint:add")
    @Log(title = "保养计划信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsPlanMaint dmsPlanMaint)
    {
        return toAjax(dmsPlanMaintService.insertDmsPlanMaint(dmsPlanMaint));
    }

    /**
     * 修改保养计划信息
     */
    @RequiresPermissions("dms:maint:edit")
    @Log(title = "保养计划信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsPlanMaint dmsPlanMaint)
    {
        return toAjax(dmsPlanMaintService.updateDmsPlanMaint(dmsPlanMaint));
    }

    /**
     * 删除保养计划信息
     */
    @RequiresPermissions("dms:maint:remove")
    @Log(title = "保养计划信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{planMaintIds}")
    public AjaxResult remove(@PathVariable Long[] planMaintIds)
    {
        return toAjax(dmsPlanMaintService.deleteDmsPlanMaintByPlanMaintIds(planMaintIds));
    }
}
