package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsRecordInspect;
import com.hw.dms.service.IDmsRecordInspectService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 巡检记录Controller
 * 
 * @author Open Platform
 * @date 2024-01-16
 */
@RestController
@RequestMapping("/dmsRecordInspect")
public class DmsRecordInspectController extends BaseController
{
    @Autowired
    private IDmsRecordInspectService dmsRecordInspectService;

    /**
     * 查询巡检记录列表
     */
    @RequiresPermissions("dms:dmsRecordInspect:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsRecordInspect dmsRecordInspect)
    {
        startPage();
        List<DmsRecordInspect> list = dmsRecordInspectService.selectDmsRecordInspectList(dmsRecordInspect);
        return getDataTable(list);
    }

    /**
     * 导出巡检记录列表
     */
    @RequiresPermissions("dms:dmsRecordInspect:export")
    @Log(title = "巡检记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsRecordInspect dmsRecordInspect)
    {
        List<DmsRecordInspect> list = dmsRecordInspectService.selectDmsRecordInspectList(dmsRecordInspect);
        ExcelUtil<DmsRecordInspect> util = new ExcelUtil<DmsRecordInspect>(DmsRecordInspect.class);
        util.exportExcel(response, list, "巡检记录数据");
    }

    /**
     * 获取巡检记录详细信息
     */
    @RequiresPermissions("dms:dmsRecordInspect:query")
    @GetMapping(value = "/{recordInspectId}")
    public AjaxResult getInfo(@PathVariable("recordInspectId") Long recordInspectId)
    {
        return success(dmsRecordInspectService.selectDmsRecordInspectByRecordInspectId(recordInspectId));
    }

    /**
     * 新增巡检记录
     */
    @RequiresPermissions("dms:dmsRecordInspect:add")
    @Log(title = "巡检记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsRecordInspect dmsRecordInspect)
    {
        return toAjax(dmsRecordInspectService.insertDmsRecordInspect(dmsRecordInspect));
    }

    /**
     * 修改巡检记录
     */
    @RequiresPermissions("dms:dmsRecordInspect:edit")
    @Log(title = "巡检记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsRecordInspect dmsRecordInspect)
    {
        return toAjax(dmsRecordInspectService.updateDmsRecordInspect(dmsRecordInspect));
    }

    /**
     * 删除巡检记录
     */
    @RequiresPermissions("dms:dmsRecordInspect:remove")
    @Log(title = "巡检记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{recordInspectIds}")
    public AjaxResult remove(@PathVariable Long[] recordInspectIds)
    {
        return toAjax(dmsRecordInspectService.deleteDmsRecordInspectByRecordInspectIds(recordInspectIds));
    }
}
