package com.hw.dms.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import com.hw.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.dms.mapper.DmsBaseMaintStandardMapper;
import com.hw.dms.domain.DmsBaseMaintStandard;
import com.hw.dms.service.IDmsBaseMaintStandardService;

/**
 * 保养标准信息Service业务层处理
 *
 * @author xins
 * @date 2024-01-05
 */
@Service
public class DmsBaseMaintStandardServiceImpl implements IDmsBaseMaintStandardService
{
    @Autowired
    private DmsBaseMaintStandardMapper dmsBaseMaintStandardMapper;

    /**
     * 查询保养标准信息
     *
     * @param maintStandardId 保养标准信息主键
     * @return 保养标准信息
     */
    @Override
    public DmsBaseMaintStandard selectDmsBaseMaintStandardByMaintStandardId(Long maintStandardId)
    {
        return dmsBaseMaintStandardMapper.selectDmsBaseMaintStandardByMaintStandardId(maintStandardId);
    }

    /**
     * 查询保养标准信息列表
     *
     * @param dmsBaseMaintStandard 保养标准信息
     * @return 保养标准信息
     */
    @Override
    public List<DmsBaseMaintStandard> selectDmsBaseMaintStandardList(DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        return dmsBaseMaintStandardMapper.selectDmsBaseMaintStandardList(dmsBaseMaintStandard);
    }

    /**
     * 新增保养标准信息
     *
     * @param dmsBaseMaintStandard 保养标准信息
     * @return 结果
     */
    @Override
    public int insertDmsBaseMaintStandard(DmsBaseMaintStandard dmsBaseMaintStandard)
    {

        LoginUser user = new LoginUser();
        dmsBaseMaintStandard.setIsFlag(1l);
        dmsBaseMaintStandard.setDeviceTypeId(0l);
        dmsBaseMaintStandard.setCreateBy(user.getUsername());
        dmsBaseMaintStandard.setCreateTime(DateUtils.getNowDate());
        return dmsBaseMaintStandardMapper.insertDmsBaseMaintStandard(dmsBaseMaintStandard);
    }

    /**
     * 修改保养标准信息
     *
     * @param dmsBaseMaintStandard 保养标准信息
     * @return 结果
     */
    @Override
    public int updateDmsBaseMaintStandard(DmsBaseMaintStandard dmsBaseMaintStandard)
    {
        LoginUser user = new LoginUser();

        dmsBaseMaintStandard.setUpdateBy(user.getUsername());
        dmsBaseMaintStandard.setUpdateTime(DateUtils.getNowDate());
        return dmsBaseMaintStandardMapper.updateDmsBaseMaintStandard(dmsBaseMaintStandard);
    }

    /**
     * 批量删除保养标准信息
     *
     * @param maintStandardIds 需要删除的保养标准信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseMaintStandardByMaintStandardIds(Long[] maintStandardIds)
    {
        return dmsBaseMaintStandardMapper.deleteDmsBaseMaintStandardByMaintStandardIds(maintStandardIds);
    }

    /**
     * 删除保养标准信息信息
     *
     * @param maintStandardId 保养标准信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseMaintStandardByMaintStandardId(Long maintStandardId)
    {
        return dmsBaseMaintStandardMapper.deleteDmsBaseMaintStandardByMaintStandardId(maintStandardId);
    }
}
