package com.hw.dms.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import com.hw.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.dms.mapper.DmsBaseSpecialdeviceParamMapper;
import com.hw.dms.domain.DmsBaseSpecialdeviceParam;
import com.hw.dms.service.IDmsBaseSpecialdeviceParamService;

/**
 * 特种设备参数信息Service业务层处理
 *
 * @author xins
 * @date 2024-01-09
 */
@Service
public class DmsBaseSpecialdeviceParamServiceImpl implements IDmsBaseSpecialdeviceParamService
{
    @Autowired
    private DmsBaseSpecialdeviceParamMapper dmsBaseSpecialdeviceParamMapper;

    /**
     * 查询特种设备参数信息
     *
     * @param specialdeviceParamId 特种设备参数信息主键
     * @return 特种设备参数信息
     */
    @Override
    public DmsBaseSpecialdeviceParam selectDmsBaseSpecialdeviceParamBySpecialdeviceParamId(Long specialdeviceParamId)
    {
        return dmsBaseSpecialdeviceParamMapper.selectDmsBaseSpecialdeviceParamBySpecialdeviceParamId(specialdeviceParamId);
    }

    /**
     * 查询特种设备参数信息列表
     *
     * @param dmsBaseSpecialdeviceParam 特种设备参数信息
     * @return 特种设备参数信息
     */
    @Override
    public List<DmsBaseSpecialdeviceParam> selectDmsBaseSpecialdeviceParamList(DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        return dmsBaseSpecialdeviceParamMapper.selectDmsBaseSpecialdeviceParamList(dmsBaseSpecialdeviceParam);
    }

    /**
     * 新增特种设备参数信息
     *
     * @param dmsBaseSpecialdeviceParam 特种设备参数信息
     * @return 结果
     */
    @Override
    public int insertDmsBaseSpecialdeviceParam(DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        LoginUser user = new LoginUser();
        dmsBaseSpecialdeviceParam.setCreateBy(user.getUsername());
        dmsBaseSpecialdeviceParam.setIsFlag(1l);
        dmsBaseSpecialdeviceParam.setCreateTime(DateUtils.getNowDate());
        return dmsBaseSpecialdeviceParamMapper.insertDmsBaseSpecialdeviceParam(dmsBaseSpecialdeviceParam);
    }

    /**
     * 修改特种设备参数信息
     *
     * @param dmsBaseSpecialdeviceParam 特种设备参数信息
     * @return 结果
     */
    @Override
    public int updateDmsBaseSpecialdeviceParam(DmsBaseSpecialdeviceParam dmsBaseSpecialdeviceParam)
    {
        LoginUser user =  new LoginUser();
        dmsBaseSpecialdeviceParam.setUpdateBy(user.getUsername());
        dmsBaseSpecialdeviceParam.setUpdateTime(DateUtils.getNowDate());
        return dmsBaseSpecialdeviceParamMapper.updateDmsBaseSpecialdeviceParam(dmsBaseSpecialdeviceParam);
    }

    /**
     * 批量删除特种设备参数信息
     *
     * @param specialdeviceParamIds 需要删除的特种设备参数信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseSpecialdeviceParamBySpecialdeviceParamIds(Long[] specialdeviceParamIds)
    {
        return dmsBaseSpecialdeviceParamMapper.deleteDmsBaseSpecialdeviceParamBySpecialdeviceParamIds(specialdeviceParamIds);
    }

    /**
     * 删除特种设备参数信息信息
     *
     * @param specialdeviceParamId 特种设备参数信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseSpecialdeviceParamBySpecialdeviceParamId(Long specialdeviceParamId)
    {
        return dmsBaseSpecialdeviceParamMapper.deleteDmsBaseSpecialdeviceParamBySpecialdeviceParamId(specialdeviceParamId);
    }
}
