package com.hw.dms.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import com.hw.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.dms.mapper.DmsBaseTransferInfoMapper;
import com.hw.dms.domain.DmsBaseTransferInfo;
import com.hw.dms.service.IDmsBaseTransferInfoService;

/**
 * 设备转移信息Service业务层处理
 *
 * @author xins
 * @date 2024-01-02
 */
@Service
public class DmsBaseTransferInfoServiceImpl implements IDmsBaseTransferInfoService
{
    @Autowired
    private DmsBaseTransferInfoMapper dmsBaseTransferInfoMapper;

    /**
     * 查询设备转移信息
     *
     * @param transferInfoId 设备转移信息主键
     * @return 设备转移信息
     */
    @Override
    public DmsBaseTransferInfo selectDmsBaseTransferInfoByTransferInfoId(Long transferInfoId)
    {
        return dmsBaseTransferInfoMapper.selectDmsBaseTransferInfoByTransferInfoId(transferInfoId);
    }

    /**
     * 查询设备转移信息列表
     *
     * @param dmsBaseTransferInfo 设备转移信息
     * @return 设备转移信息
     */
    @Override
    public List<DmsBaseTransferInfo> selectDmsBaseTransferInfoList(DmsBaseTransferInfo dmsBaseTransferInfo)
    {
        return dmsBaseTransferInfoMapper.selectDmsBaseTransferInfoList(dmsBaseTransferInfo);
    }

    /**
     * 新增设备转移信息
     *
     * @param dmsBaseTransferInfo 设备转移信息
     * @return 结果
     */
    @Override
    public int insertDmsBaseTransferInfo(DmsBaseTransferInfo dmsBaseTransferInfo)
    {
        LoginUser loginUser = new LoginUser();
        dmsBaseTransferInfo.setCreateBy(loginUser.getUsername());
        dmsBaseTransferInfo.setCreateTime(DateUtils.getNowDate());
        return dmsBaseTransferInfoMapper.insertDmsBaseTransferInfo(dmsBaseTransferInfo);
    }

    /**
     * 修改设备转移信息
     *
     * @param dmsBaseTransferInfo 设备转移信息
     * @return 结果
     */
    @Override
    public int updateDmsBaseTransferInfo(DmsBaseTransferInfo dmsBaseTransferInfo)
    {
        LoginUser loginUser = new LoginUser();
        dmsBaseTransferInfo.setUpdateBy(loginUser.getUsername());
        dmsBaseTransferInfo.setUpdateTime(DateUtils.getNowDate());
        return dmsBaseTransferInfoMapper.updateDmsBaseTransferInfo(dmsBaseTransferInfo);
    }

    /**
     * 批量删除设备转移信息
     *
     * @param transferInfoIds 需要删除的设备转移信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseTransferInfoByTransferInfoIds(Long[] transferInfoIds)
    {
        return dmsBaseTransferInfoMapper.deleteDmsBaseTransferInfoByTransferInfoIds(transferInfoIds);
    }

    /**
     * 删除设备转移信息信息
     *
     * @param transferInfoId 设备转移信息主键
     * @return 结果
     */
    @Override
    public int deleteDmsBaseTransferInfoByTransferInfoId(Long transferInfoId)
    {
        return dmsBaseTransferInfoMapper.deleteDmsBaseTransferInfoByTransferInfoId(transferInfoId);
    }
}
