package com.hw.dms.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import com.hw.system.api.model.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.dms.mapper.DmsPlanLubeMapper;
import com.hw.dms.domain.DmsPlanLube;
import com.hw.dms.service.IDmsPlanLubeService;

/**
 * 润滑计划Service业务层处理
 *
 * @author Open Platform
 * @date 2024-01-12
 */
@Service
public class DmsPlanLubeServiceImpl implements IDmsPlanLubeService
{
    @Autowired
    private DmsPlanLubeMapper dmsPlanLubeMapper;

    /**
     * 查询润滑计划
     *
     * @param planLubeId 润滑计划主键
     * @return 润滑计划
     */
    @Override
    public DmsPlanLube selectDmsPlanLubeByPlanLubeId(Long planLubeId)
    {
        return dmsPlanLubeMapper.selectDmsPlanLubeByPlanLubeId(planLubeId);
    }

    /**
     * 查询润滑计划列表
     *
     * @param dmsPlanLube 润滑计划
     * @return 润滑计划
     */
    @Override
    public List<DmsPlanLube> selectDmsPlanLubeList(DmsPlanLube dmsPlanLube)
    {
        return dmsPlanLubeMapper.selectDmsPlanLubeList(dmsPlanLube);
    }

    /**
     * 新增润滑计划
     *
     * @param dmsPlanLube 润滑计划
     * @return 结果
     */
    @Override
    public int insertDmsPlanLube(DmsPlanLube dmsPlanLube)
    {
        LoginUser user = new LoginUser();
        dmsPlanLube.setIsFlag("1");
        dmsPlanLube.setCreateBy(user.getUsername());
        dmsPlanLube.setCreateTime(DateUtils.getNowDate());
        return dmsPlanLubeMapper.insertDmsPlanLube(dmsPlanLube);
    }

    /**
     * 修改润滑计划
     *
     * @param dmsPlanLube 润滑计划
     * @return 结果
     */
    @Override
    public int updateDmsPlanLube(DmsPlanLube dmsPlanLube)
    {
        dmsPlanLube.setUpdateTime(DateUtils.getNowDate());
        return dmsPlanLubeMapper.updateDmsPlanLube(dmsPlanLube);
    }

    /**
     * 批量删除润滑计划
     *
     * @param planLubeIds 需要删除的润滑计划主键
     * @return 结果
     */
    @Override
    public int deleteDmsPlanLubeByPlanLubeIds(Long[] planLubeIds)
    {
        return dmsPlanLubeMapper.deleteDmsPlanLubeByPlanLubeIds(planLubeIds);
    }

    /**
     * 删除润滑计划信息
     *
     * @param planLubeId 润滑计划主键
     * @return 结果
     */
    @Override
    public int deleteDmsPlanLubeByPlanLubeId(Long planLubeId)
    {
        return dmsPlanLubeMapper.deleteDmsPlanLubeByPlanLubeId(planLubeId);
    }
}
