package com.hw.ems.base.service.impl;

import java.util.List;

import com.hw.common.core.utils.DateUtils;
import com.hw.ems.base.domain.BaseCollectCommunicate;
import com.hw.ems.base.mapper.BaseCollectCommunicateMapper;
import com.hw.ems.base.service.IBaseCollectCommunicateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 集中器通讯信息Service业务层处理
 *
 * @author sf
 * @date 2023-04-20
 */
@Service
public class BaseCollectCommunicateServiceImpl implements IBaseCollectCommunicateService {
    @Autowired
    private BaseCollectCommunicateMapper baseCollectCommunicateMapper;

    /**
     * 查询集中器通讯信息
     *
     * @param objid 集中器通讯信息主键
     * @return 集中器通讯信息
     */
    @Override
    //@DS("#header.poolName")
    public BaseCollectCommunicate selectBaseCollectCommunicateByObjid(Long objid) {
        return baseCollectCommunicateMapper.selectBaseCollectCommunicateByObjid(objid);
    }

    /**
     * 查询集中器通讯信息列表
     *
     * @param baseCollectCommunicate 集中器通讯信息
     * @return 集中器通讯信息
     */
    @Override
    //@DS("#header.poolName")
    public List<BaseCollectCommunicate> selectBaseCollectCommunicateList(BaseCollectCommunicate baseCollectCommunicate) {
        return baseCollectCommunicateMapper.selectBaseCollectCommunicateList(baseCollectCommunicate);
    }

    /**
     * 新增集中器通讯信息
     *
     * @param baseCollectCommunicate 集中器通讯信息
     * @return 结果
     */
    @Override
    //@DS("#header.poolName")
    public int insertBaseCollectCommunicate(BaseCollectCommunicate baseCollectCommunicate) {
        baseCollectCommunicate.setCreateTime(DateUtils.getNowDate());
        return baseCollectCommunicateMapper.insertBaseCollectCommunicate(baseCollectCommunicate);
    }

    /**
     * 修改集中器通讯信息
     *
     * @param baseCollectCommunicate 集中器通讯信息
     * @return 结果
     */
    @Override
    //@DS("#header.poolName")
    public int updateBaseCollectCommunicate(BaseCollectCommunicate baseCollectCommunicate) {
        baseCollectCommunicate.setUpdateTime(DateUtils.getNowDate());
        return baseCollectCommunicateMapper.updateBaseCollectCommunicate(baseCollectCommunicate);
    }

    /**
     * 批量删除集中器通讯信息
     *
     * @param objids 需要删除的集中器通讯信息主键
     * @return 结果
     */
    @Override
    //@DS("#header.poolName")
    public int deleteBaseCollectCommunicateByObjids(Long[] objids) {
        return baseCollectCommunicateMapper.deleteBaseCollectCommunicateByObjids(objids);
    }

    /**
     * 删除集中器通讯信息信息
     *
     * @param objid 集中器通讯信息主键
     * @return 结果
     */
    @Override
    //@DS("#header.poolName")
    public int deleteBaseCollectCommunicateByObjid(Long objid) {
        return baseCollectCommunicateMapper.deleteBaseCollectCommunicateByObjid(objid);
    }
}
