package com.hw.ems.base.service.impl;

import java.util.List;

import com.hw.common.core.utils.DateUtils;
import com.hw.ems.base.domain.BaseLineLoss;
import com.hw.ems.base.mapper.BaseLineLossMapper;
import com.hw.ems.base.service.IBaseLineLossService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 线损对象信息Service业务层处理
 *
 * @author sf
 * @date 2023-04-20
 */
@Service
public class BaseLineLossServiceImpl implements IBaseLineLossService {
    @Autowired
    private BaseLineLossMapper baseLineLossMapper;

    /**
     * 查询线损对象信息
     *
     * @param objid 线损对象信息主键
     * @return 线损对象信息
     */
    @Override
    //@DS("#header.poolName")
    public BaseLineLoss selectBaseLineLossByObjid(Long objid) {
        return baseLineLossMapper.selectBaseLineLossByObjid(objid);
    }
    //todo 模糊查询
    @Override
    public List<BaseLineLoss> selectBaseLineLossListLike(BaseLineLoss baseLineLoss) {
        return baseLineLossMapper.selectBaseLineLossListLike(baseLineLoss);
    }

    /**
     * 查询线损对象信息列表
     *
     * @param baseLineLoss 线损对象信息
     * @return 线损对象信息
     */
    @Override
    //@DS("#header.poolName")
    public List<BaseLineLoss> selectBaseLineLossList(BaseLineLoss baseLineLoss) {
        return baseLineLossMapper.selectBaseLineLossList(baseLineLoss);
    }



    /**
     * 新增线损对象信息
     *
     * @param baseLineLoss 线损对象信息
     * @return 结果
     */
    @Override
    //@DS("#header.poolName")
    public int insertBaseLineLoss(BaseLineLoss baseLineLoss) {
        baseLineLoss.setCreateTime(DateUtils.getNowDate());
        return baseLineLossMapper.insertBaseLineLoss(baseLineLoss);
    }

    /**
     * 修改线损对象信息
     *
     * @param baseLineLoss 线损对象信息
     * @return 结果
     */
    @Override
    //@DS("#header.poolName")
    public int updateBaseLineLoss(BaseLineLoss baseLineLoss) {
        baseLineLoss.setUpdateTime(DateUtils.getNowDate());
        return baseLineLossMapper.updateBaseLineLoss(baseLineLoss);
    }

    /**
     * 批量删除线损对象信息
     *
     * @param objids 需要删除的线损对象信息主键
     * @return 结果
     */
    @Override
    //@DS("#header.poolName")
    public int deleteBaseLineLossByObjids(Long[] objids) {
        return baseLineLossMapper.deleteBaseLineLossByObjids(objids);
    }

    /**
     * 删除线损对象信息信息
     *
     * @param objid 线损对象信息主键
     * @return 结果
     */
    @Override
    //@DS("#header.poolName")
    public int deleteBaseLineLossByObjid(Long objid) {
        return baseLineLossMapper.deleteBaseLineLossByObjid(objid);
    }
}
