package com.hw.mes.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.mes.mapper.MesBindBarcodeMapper;
import com.hw.mes.domain.MesBindBarcode;
import com.hw.mes.service.IMesBindBarcodeService;

/**
 * 条码绑定信息Service业务层处理
 * 
 * @author xins
 * @date 2023-12-28
 */
@Service
public class MesBindBarcodeServiceImpl implements IMesBindBarcodeService 
{
    @Autowired
    private MesBindBarcodeMapper mesBindBarcodeMapper;

    /**
     * 查询条码绑定信息
     * 
     * @param bindBarcodeId 条码绑定信息主键
     * @return 条码绑定信息
     */
    @Override
    public MesBindBarcode selectMesBindBarcodeByBindBarcodeId(Long bindBarcodeId)
    {
        return mesBindBarcodeMapper.selectMesBindBarcodeByBindBarcodeId(bindBarcodeId);
    }

    /**
     * 查询条码绑定信息列表
     * 
     * @param mesBindBarcode 条码绑定信息
     * @return 条码绑定信息
     */
    @Override
    public List<MesBindBarcode> selectMesBindBarcodeList(MesBindBarcode mesBindBarcode)
    {
        return mesBindBarcodeMapper.selectMesBindBarcodeList(mesBindBarcode);
    }

    /**
     * 新增条码绑定信息
     * 
     * @param mesBindBarcode 条码绑定信息
     * @return 结果
     */
    @Override
    public int insertMesBindBarcode(MesBindBarcode mesBindBarcode)
    {
        mesBindBarcode.setCreateTime(DateUtils.getNowDate());
        return mesBindBarcodeMapper.insertMesBindBarcode(mesBindBarcode);
    }

    /**
     * 修改条码绑定信息
     * 
     * @param mesBindBarcode 条码绑定信息
     * @return 结果
     */
    @Override
    public int updateMesBindBarcode(MesBindBarcode mesBindBarcode)
    {
        mesBindBarcode.setUpdateTime(DateUtils.getNowDate());
        return mesBindBarcodeMapper.updateMesBindBarcode(mesBindBarcode);
    }

    /**
     * 批量删除条码绑定信息
     * 
     * @param bindBarcodeIds 需要删除的条码绑定信息主键
     * @return 结果
     */
    @Override
    public int deleteMesBindBarcodeByBindBarcodeIds(Long[] bindBarcodeIds)
    {
        return mesBindBarcodeMapper.deleteMesBindBarcodeByBindBarcodeIds(bindBarcodeIds);
    }

    /**
     * 删除条码绑定信息信息
     * 
     * @param bindBarcodeId 条码绑定信息主键
     * @return 结果
     */
    @Override
    public int deleteMesBindBarcodeByBindBarcodeId(Long bindBarcodeId)
    {
        return mesBindBarcodeMapper.deleteMesBindBarcodeByBindBarcodeId(bindBarcodeId);
    }
}
