package com.hw.system.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import com.hw.common.core.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;
import com.hw.system.domain.WfProcessActivityAuth;
import com.hw.system.mapper.WfProcessActivityMapper;
import com.hw.system.domain.WfProcessActivity;
import com.hw.system.service.IWfProcessActivityService;

/**
 * 工单流程节点步骤Service业务层处理
 * 
 * @author xins
 * @date 2024-01-19
 */
@Service
public class WfProcessActivityServiceImpl implements IWfProcessActivityService 
{
    @Autowired
    private WfProcessActivityMapper wfProcessActivityMapper;

    /**
     * 查询工单流程节点步骤
     * 
     * @param processActivityId 工单流程节点步骤主键
     * @return 工单流程节点步骤
     */
    @Override
    public WfProcessActivity selectWfProcessActivityByProcessActivityId(Long processActivityId)
    {
        return wfProcessActivityMapper.selectWfProcessActivityByProcessActivityId(processActivityId);
    }

    /**
     * 查询工单流程节点步骤列表
     * 
     * @param wfProcessActivity 工单流程节点步骤
     * @return 工单流程节点步骤
     */
    @Override
    public List<WfProcessActivity> selectWfProcessActivityList(WfProcessActivity wfProcessActivity)
    {
        return wfProcessActivityMapper.selectWfProcessActivityList(wfProcessActivity);
    }

    /**
     * 新增工单流程节点步骤
     * 
     * @param wfProcessActivity 工单流程节点步骤
     * @return 结果
     */
    @Transactional
    @Override
    public int insertWfProcessActivity(WfProcessActivity wfProcessActivity)
    {
        wfProcessActivity.setCreateTime(DateUtils.getNowDate());
        int rows = wfProcessActivityMapper.insertWfProcessActivity(wfProcessActivity);
        insertWfProcessActivityAuth(wfProcessActivity);
        return rows;
    }

    /**
     * 修改工单流程节点步骤
     * 
     * @param wfProcessActivity 工单流程节点步骤
     * @return 结果
     */
    @Transactional
    @Override
    public int updateWfProcessActivity(WfProcessActivity wfProcessActivity)
    {
        wfProcessActivity.setUpdateTime(DateUtils.getNowDate());
        wfProcessActivityMapper.deleteWfProcessActivityAuthByProcessActivityId(wfProcessActivity.getProcessActivityId());
        insertWfProcessActivityAuth(wfProcessActivity);
        return wfProcessActivityMapper.updateWfProcessActivity(wfProcessActivity);
    }

    /**
     * 批量删除工单流程节点步骤
     * 
     * @param processActivityIds 需要删除的工单流程节点步骤主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteWfProcessActivityByProcessActivityIds(Long[] processActivityIds)
    {
        wfProcessActivityMapper.deleteWfProcessActivityAuthByProcessActivityIds(processActivityIds);
        return wfProcessActivityMapper.deleteWfProcessActivityByProcessActivityIds(processActivityIds);
    }

    /**
     * 删除工单流程节点步骤信息
     * 
     * @param processActivityId 工单流程节点步骤主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteWfProcessActivityByProcessActivityId(Long processActivityId)
    {
        wfProcessActivityMapper.deleteWfProcessActivityAuthByProcessActivityId(processActivityId);
        return wfProcessActivityMapper.deleteWfProcessActivityByProcessActivityId(processActivityId);
    }

    /**
     * 新增工单流程节点步骤权限信息
     * 
     * @param wfProcessActivity 工单流程节点步骤对象
     */
    public void insertWfProcessActivityAuth(WfProcessActivity wfProcessActivity)
    {
        List<WfProcessActivityAuth> wfProcessActivityAuthList = wfProcessActivity.getWfProcessActivityAuthList();
        Long processActivityId = wfProcessActivity.getProcessActivityId();
        if (StringUtils.isNotNull(wfProcessActivityAuthList))
        {
            List<WfProcessActivityAuth> list = new ArrayList<WfProcessActivityAuth>();
            for (WfProcessActivityAuth wfProcessActivityAuth : wfProcessActivityAuthList)
            {
                wfProcessActivityAuth.setProcessActivityId(processActivityId);
                list.add(wfProcessActivityAuth);
            }
            if (list.size() > 0)
            {
                wfProcessActivityMapper.batchWfProcessActivityAuth(list);
            }
        }
    }
}
