package com.hw.system.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.system.mapper.WfProcessMapper;
import com.hw.system.domain.WfProcess;
import com.hw.system.service.IWfProcessService;

/**
 * 工单流程Service业务层处理
 * 
 * @author xins
 * @date 2024-01-19
 */
@Service
public class WfProcessServiceImpl implements IWfProcessService 
{
    @Autowired
    private WfProcessMapper wfProcessMapper;

    /**
     * 查询工单流程
     * 
     * @param wfProcessId 工单流程主键
     * @return 工单流程
     */
    @Override
    public WfProcess selectWfProcessByWfProcessId(Long wfProcessId)
    {
        return wfProcessMapper.selectWfProcessByWfProcessId(wfProcessId);
    }

    /**
     * 查询工单流程列表
     * 
     * @param wfProcess 工单流程
     * @return 工单流程
     */
    @Override
    public List<WfProcess> selectWfProcessList(WfProcess wfProcess)
    {
        return wfProcessMapper.selectWfProcessList(wfProcess);
    }

    /**
     * 新增工单流程
     * 
     * @param wfProcess 工单流程
     * @return 结果
     */
    @Override
    public int insertWfProcess(WfProcess wfProcess)
    {
        wfProcess.setCreateTime(DateUtils.getNowDate());
        return wfProcessMapper.insertWfProcess(wfProcess);
    }

    /**
     * 修改工单流程
     * 
     * @param wfProcess 工单流程
     * @return 结果
     */
    @Override
    public int updateWfProcess(WfProcess wfProcess)
    {
        wfProcess.setUpdateTime(DateUtils.getNowDate());
        return wfProcessMapper.updateWfProcess(wfProcess);
    }

    /**
     * 批量删除工单流程
     * 
     * @param wfProcessIds 需要删除的工单流程主键
     * @return 结果
     */
    @Override
    public int deleteWfProcessByWfProcessIds(Long[] wfProcessIds)
    {
        return wfProcessMapper.deleteWfProcessByWfProcessIds(wfProcessIds);
    }

    /**
     * 删除工单流程信息
     * 
     * @param wfProcessId 工单流程主键
     * @return 结果
     */
    @Override
    public int deleteWfProcessByWfProcessId(Long wfProcessId)
    {
        return wfProcessMapper.deleteWfProcessByWfProcessId(wfProcessId);
    }
}
