package com.hw.wms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.wms.domain.WmsProductOutstock;
import com.hw.wms.service.IWmsProductOutstockService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 成品出库记录Controller
 * 
 * @author xs
 * @date 2023-12-20
 */
@RestController
@RequestMapping("/productoutstock")
public class WmsProductOutstockController extends BaseController
{
    @Autowired
    private IWmsProductOutstockService wmsProductOutstockService;

    /**
     * 查询成品出库记录列表
     */
    @RequiresPermissions("wms:productoutstock:list")
    @GetMapping("/list")
    public TableDataInfo list(WmsProductOutstock wmsProductOutstock)
    {
        startPage();
        List<WmsProductOutstock> list = wmsProductOutstockService.selectWmsProductOutstockList(wmsProductOutstock);
        return getDataTable(list);
    }

    /**
     * 导出成品出库记录列表
     */
    @RequiresPermissions("wms:productoutstock:export")
    @Log(title = "成品出库记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WmsProductOutstock wmsProductOutstock)
    {
        List<WmsProductOutstock> list = wmsProductOutstockService.selectWmsProductOutstockList(wmsProductOutstock);
        ExcelUtil<WmsProductOutstock> util = new ExcelUtil<WmsProductOutstock>(WmsProductOutstock.class);
        util.exportExcel(response, list, "成品出库记录数据");
    }

    /**
     * 获取成品出库记录详细信息
     */
    @RequiresPermissions("wms:productoutstock:query")
    @GetMapping(value = "/{productOutstockId}")
    public AjaxResult getInfo(@PathVariable("productOutstockId") Long productOutstockId)
    {
        return success(wmsProductOutstockService.selectWmsProductOutstockByProductOutstockId(productOutstockId));
    }

    /**
     * 新增成品出库记录
     */
    @RequiresPermissions("wms:productoutstock:add")
    @Log(title = "成品出库记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WmsProductOutstock wmsProductOutstock)
    {
        return toAjax(wmsProductOutstockService.insertWmsProductOutstock(wmsProductOutstock));
    }

    /**
     * 修改成品出库记录
     */
    @RequiresPermissions("wms:productoutstock:edit")
    @Log(title = "成品出库记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WmsProductOutstock wmsProductOutstock)
    {
        return toAjax(wmsProductOutstockService.updateWmsProductOutstock(wmsProductOutstock));
    }

    /**
     * 删除成品出库记录
     */
    @RequiresPermissions("wms:productoutstock:remove")
    @Log(title = "成品出库记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{productOutstockIds}")
    public AjaxResult remove(@PathVariable Long[] productOutstockIds)
    {
        return toAjax(wmsProductOutstockService.deleteWmsProductOutstockByProductOutstockIds(productOutstockIds));
    }
}
